Core functions — XRCEA 0.2 documentation

# Core functions

Input data

class core.idata.XrayData(obj=None)
  Parameters:

    fname (string) – Path to file with X-ray diffraction data.

  abstraction2plot(abstr: Union[str, Dict[str, Dict]])
  property corr_intens

    correct intensity

  display()

    Display X-ray data as plot.

  from_obj(xrd)

    Get X-ray data from dict

  get_obj()

    Convets X-ray data into object.

  open(fname)

    Open file with X-ray data.

    Parameters:

      fname (string) – Path to file with X-ray data.

  static open_xrd(fname)

    Open xrd or dat file.

    Parameters:

      fname (string) – Path to xrd or dat file.

  rev_intens(Icor)

    reverse correct intensity

core.idata.ask_about_sample(sdict)

  Ask some details about the sample

core.idata.introduce_input()

  Introduce input

core.idata.open_xrd(fname)

  Open X-ray data file.

Operate with project file

class core.project.vi_Project(project)

## Visualization

core.vi.ask_question(title, question)
  Parameters:

    - title (string) – Title of the window.

    - question (string) – A simple question.

core.vi.copy_to_clipboard(text)
  Parameters:

    text (string) – Text to copy into clipboard.

core.vi.gui_exit()

  Quit the GUI.

core.vi.input_dialog(title, question, fields, parent=None)
  Parameters:

    - title (string) – Title of the window.

    - question (string or None) – Question to ask.

    - fields (list) – List of tuples (name, value, [optional]).

    - parent (NoneType) – Not used.

core.vi.print_error(title, info)
  Parameters:

    - title (string) – Title of the window.

    - info (string) – Information about error.

core.vi.print_information(title, info)
  Parameters:

    - title (string) – Title of the window.

    - info (string) – Information itself.

core.vi.print_status(status)
  Parameters:

    status (string) – Status to print into statusbar.

core.vi.register_dialog(dlg)

  Send a dlg function to execution queue, which should be executed in GUI thread.

  Parameters:

    dlg (callable) – Some function, which gets no parameters.